# ColdTOFU

Time of flight utilities - a simple package built using numpy and scipy to analyze absorption and fluorescence images
from cold atoms experiments.

`pip install ColdTOFU`

or

`pip install -e .` from the source directory to modify the code according to your usage.

[![DOI](https://zenodo.org/badge/544229576.svg)](https://zenodo.org/badge/latestdoi/544229576)

See requirements.txt for the necessary packages.

See documentation and examples [here](https://chetanmadasu.github.io/examples.html)
